CCL: ccl_test_growth Namespace Reference

CCL

Functions | Variables
ccl_test_growth Namespace Reference

## Functions
def | read_growth_test_file ()
def | compare_growth (z, gfac_bench, Omega_v, w0, wa)
def | test_growth_model_0 ()
def | test_growth_model_1 ()
def | test_growth_model_2 ()
def | test_growth_model_3 ()
def | test_growth_model_4 ()
def | test_mgrowth ()

## Variables
int | GROWTH_TOLERANCE = 1e-4
float | Omega_c = 0.25
float | Omega_b = 0.05
int | N_nu_rel = 0.
int | N_nu_mass = 0.
int | m_nu = 0.
float | h = 0.7
float | A_s = 2.1e-9
float | n_s = 0.96
| Omega_v_vals = np.array([0.7, 0.7, 0.7, 0.65, 0.75])
| w0_vals = np.array([-1.0, -0.9, -0.9, -0.9, -0.9])
| wa_vals = np.array([0.0, 0.0, 0.1, 0.1, 0.1])

## Function Documentation

## ◆ compare_growth()

def ccl_test_growth.compare_growth | ( |  | z,
|  |  | gfac_bench,
|  |  | Omega_v,
|  |  | w0,
|  |  | wa
| ) |  |

    Compare growth factor calculated by pyccl with the values in the benchmark
    file. This test only works if radiation is explicitly set to 0.

## ◆ read_growth_test_file()

def ccl_test_growth.read_growth_test_file | ( |  | ) |

    Read the file containing all the radial comoving distance benchmarks
    (distances are in Mpc/h)

## ◆ test_growth_model_0()

def ccl_test_growth.test_growth_model_0 | ( |  | ) |

## ◆ test_growth_model_1()

def ccl_test_growth.test_growth_model_1 | ( |  | ) |

## ◆ test_growth_model_2()

def ccl_test_growth.test_growth_model_2 | ( |  | ) |

## ◆ test_growth_model_3()

def ccl_test_growth.test_growth_model_3 | ( |  | ) |

## ◆ test_growth_model_4()

def ccl_test_growth.test_growth_model_4 | ( |  | ) |

## ◆ test_mgrowth()

def ccl_test_growth.test_mgrowth | ( |  | ) |

    Compare the modified growth function computed by CCL against the exact
    result for a particular modification of the growth rate.

## Variable Documentation

## ◆ A_s

float ccl_test_growth.A_s = 2.1e-9

## ◆ GROWTH_TOLERANCE

int ccl_test_growth.GROWTH_TOLERANCE = 1e-4

## ◆ h

float ccl_test_growth.h = 0.7

## ◆ m_nu

int ccl_test_growth.m_nu = 0.

## ◆ N_nu_mass

int ccl_test_growth.N_nu_mass = 0.

## ◆ N_nu_rel

int ccl_test_growth.N_nu_rel = 0.

## ◆ n_s

float ccl_test_growth.n_s = 0.96

## ◆ Omega_b

float ccl_test_growth.Omega_b = 0.05

## ◆ Omega_c

float ccl_test_growth.Omega_c = 0.25

## ◆ Omega_v_vals

ccl_test_growth.Omega_v_vals = np.array([0.7, 0.7, 0.7, 0.65, 0.75])

## ◆ w0_vals

ccl_test_growth.w0_vals = np.array([-1.0, -0.9, -0.9, -0.9, -0.9])

## ◆ wa_vals

ccl_test_growth.wa_vals = np.array([0.0, 0.0, 0.1, 0.1, 0.1])